==> james-project-3.7.6-source-release.zip: james-project/server/mailet/integration-testing/src/test/java/org/apache/james/mailets/flow/AddRecipient.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.mailets.flow;

import static org.apache.james.mailets.configuration.Constants.RECIPIENT2;

import javax.mail.internet.AddressException;

import org.apache.james.core.MailAddress;
import org.apache.mailet.Mail;
import org.apache.mailet.base.GenericMailet;

import com.google.common.collect.ImmutableList;

public class AddRecipient extends GenericMailet {
    @Override
    public void service(Mail mail) throws AddressException {
        mail.setRecipients(ImmutableList.<MailAddress>builder()
            .add(new MailAddress(RECIPIENT2))
            .addAll(mail.getRecipients())
            .build());
    }
}

==> james-project-3.9.0-source-release.zip: james-project/server/mailet/integration-testing/src/test/java/org/apache/james/mailets/flow/AddRecipient.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.mailets.flow;

import static org.apache.james.mailets.configuration.Constants.RECIPIENT2;

import jakarta.mail.internet.AddressException;

import org.apache.james.core.MailAddress;
import org.apache.mailet.Mail;
import org.apache.mailet.base.GenericMailet;

import com.google.common.collect.ImmutableList;

public class AddRecipient extends GenericMailet {
    @Override
    public void service(Mail mail) throws AddressException {
        mail.setRecipients(ImmutableList.<MailAddress>builder()
            .add(new MailAddress(RECIPIENT2))
            .addAll(mail.getRecipients())
            .build());
    }
}
